#!/usr/bin/env node
import { rmSync } from "fs";
import { join } from "path";

const dir = join(process.cwd(), "public");
const viteManifestFile = join(dir, "vite-manifest.json");

const deleteViteManifest = () =>
  rmSync(viteManifestFile, {
    force: true,
  });

/**
 * We are facing various issues with build reproducibility all linked with the `vite-manifest.json` that is generated by SvelteKit + ViteJS.
 *
 * Those open are:
 * - https://github.com/sveltejs/kit/issues/8290
 * - https://github.com/sveltejs/kit/issues/8291
 *
 * We can solve above issues with workarounds, but, as we actually do not need the `vite-manifest.json` as we do not process it in the backend, we can just remove it.
 * See https://vitejs.dev/guide/backend-integration.html for some explanation about the usage of the file.
 *
 * Note that we do this "manually" because SvelteKit has currently no option to disable the script.
 */
deleteViteManifest();
